@@ -1,6 +1,6 @@
 package icon
 
-func InitIcon(nerdfont bool) {
+func InitIcon(nerdfont bool, directoryIconColor string) {
 	if !nerdfont {
 		Space = ""
 		SuperfileIcon = ""
@@ -34,4 +34,12 @@ func InitIcon(nerdfont bool) {
 		SortAsc = ""
 		SortDesc = ""
 	}
+
+	if directoryIconColor == "" {
+		directoryIconColor = "NONE" // Dark yellowish
+	}
+	Folders["folder"] = IconStyle{
+		Icon:  "\uf07b", // Printable Rune : ""
+		Color: directoryIconColor,
+	}
 }
