@@ -2,9 +2,7 @@ package internal
 
 import "github.com/charmbracelet/lipgloss"
 
-var (
-	wheelRunTime = 5
-)
+var wheelRunTime = 5
 
 var (
 	filePanelBorderColor lipgloss.Color
@@ -84,12 +82,13 @@ type ThemeType struct {
 	ModalFG      string `toml:"modal_fg"`
 
 	// Special Color
-	Cursor        string   `toml:"cursor"`
-	Correct       string   `toml:"correct"`
-	Error         string   `toml:"error"`
-	Hint          string   `toml:"hint"`
-	Cancel        string   `toml:"cancel"`
-	GradientColor []string `toml:"gradient_color"`
+	Cursor             string   `toml:"cursor"`
+	Correct            string   `toml:"correct"`
+	Error              string   `toml:"error"`
+	Hint               string   `toml:"hint"`
+	Cancel             string   `toml:"cancel"`
+	GradientColor      []string `toml:"gradient_color"`
+	DirectoryIconColor string   `toml:"directory_icon_color"`
 
 	// File Panel Special Items
 	FilePanelTopDirectoryIcon string `toml:"file_panel_top_directory_icon"`
@@ -122,6 +121,7 @@ type ConfigType struct {
 	AutoCheckUpdate        bool   `toml:"auto_check_update" comment:"\nAuto check for update"`
 	CdOnQuit               bool   `toml:"cd_on_quit" comment:"\nCd on quit (For more details, please check out https://superfile.netlify.app/configure/superfile-config/#cd_on_quit)"`
 	DefaultOpenFilePreview bool   `toml:"default_open_file_preview" comment:"\nWhether to open file preview automatically every time superfile is opened."`
+	ShowImagePreview       bool   `toml:"show_image_preview" comment:"\nWhether to show image preview."`
 	DefaultDirectory       string `toml:"default_directory" comment:"\nThe path of the first file panel when superfile is opened."`
 	FileSizeUseSI          bool   `toml:"file_size_use_si" comment:"\nDisplay file sizes using powers of 1000 (kB, MB, GB) instead of powers of 1024 (KiB, MiB, GiB)."`
 	DefaultSortType        int    `toml:"default_sort_type" comment:"\nDefault sort type (0: Name, 1: Size, 2: Date Modified)."`
@@ -129,10 +129,11 @@ type ConfigType struct {
 	CaseSensitiveSort      bool   `toml:"case_sensitive_sort" comment:"\nCase sensitive sort by name (captal \"B\" comes before \"a\" if true)."`
 	Debug                  bool   `toml:"debug" comment:"\nWhether to enable debug mode."`
 
-	Nerdfont              bool `toml:"nerdfont" comment:"\n================   Style =================\n\n If you don't have or don't want Nerdfont installed you can turn this off"`
-	TransparentBackground bool `toml:"transparent_background" comment:"\nSet transparent background or not (this only work when your terminal background is transparent)"`
-	FilePreviewWidth      int  `toml:"file_preview_width" comment:"\nFile preview width allow '0' (this mean same as file panel),'x' x must be less than 10 and greater than 1 (This means that the width of the file preview will be one xth of the total width.)"`
-	SidebarWidth          int  `toml:"sidebar_width" comment:"\nThe length of the sidebar. If you don't want to display the sidebar, you can input 0 directly. If you want to display the value, please place it in the range of 3-20."`
+	Nerdfont              bool   `toml:"nerdfont" comment:"\n================   Style =================\n\n If you don't have or don't want Nerdfont installed you can turn this off"`
+	TransparentBackground bool   `toml:"transparent_background" comment:"\nSet transparent background or not (this only work when your terminal background is transparent)"`
+	FilePreviewWidth      int    `toml:"file_preview_width" comment:"\nFile preview width allow '0' (this mean same as file panel),'x' x must be less than 10 and greater than 1 (This means that the width of the file preview will be one xth of the total width.)"`
+	CodePreviewer         string `toml:"code_previewer" comment:"\nWhether to use the builtin syntax highlighting with chroma or use bat. Values: \"\" for builtin chroma, \"bat\" for bat"`
+	SidebarWidth          int    `toml:"sidebar_width" comment:"\nThe length of the sidebar. If you don't want to display the sidebar, you can input 0 directly. If you want to display the value, please place it in the range of 3-20."`
 
 	BorderTop         string `toml:"border_top" comment:"\nBorder style"`
 	BorderBottom      string `toml:"border_bottom"`
