@@ -3,11 +3,13 @@ package internal
 import (
 	"fmt"
 	"io"
+	"log/slog"
 	"os"
 	"path/filepath"
 	"runtime"
 	"strings"
 
+	trash_win "github.com/hymkor/trash-go"
 	"github.com/rkoesters/xdg/trash"
 	variable "github.com/yorukot/superfile/src/config"
 	"github.com/yorukot/superfile/src/config/icon"
@@ -143,25 +145,26 @@ func copyFile(src, dst string, srcInfo os.FileInfo) error {
 
 // Move file to trash can and can auto switch macos trash can or linux trash can
 func trashMacOrLinux(src string) error {
+	var err error
 	if runtime.GOOS == "darwin" {
-		err := moveElement(src, filepath.Join(variable.HomeDir, ".Trash", filepath.Base(src)))
-		if err != nil {
-			outPutLog("Delete single item function move file to trash can error", err)
-		}
+		err = moveElement(src, filepath.Join(variable.DarwinTrashDirectory, filepath.Base(src)))
+	} else if runtime.GOOS == "windows" {
+		err = trash_win.Throw(src)
 	} else {
-		err := trash.Trash(src)
-		if err != nil {
-			outPutLog("Paste item function move file to trash can error", err)
-		}
+		err = trash.Trash(src)
 	}
-	return nil
+	if err != nil {
+		slog.Error("Error while delete single item function move file to trash can", "error", err)
+	}
+	return err
 }
 
 // pasteDir handles directory copying with progress tracking
-func pasteDir(src, dst string, id string, m model) (model, error) {
+// model would only have changes in m.processBarModel.process[id]
+func pasteDir(src, dst string, id string, m *model) error {
 	dst, err := renameIfDuplicate(dst)
 	if err != nil {
-		return m, err
+		return err
 	}
 
 	// Check if we can do a fast move within the same partition
@@ -170,7 +173,7 @@ func pasteDir(src, dst string, id string, m model) (model, error) {
 		// For cut operations on same partition, try fast rename first
 		err = os.Rename(src, dst)
 		if err == nil {
-			return m, nil
+			return nil
 		}
 		// If rename fails, fall back to manual copy
 	}
@@ -239,16 +242,16 @@ func pasteDir(src, dst string, id string, m model) (model, error) {
 	})
 
 	if err != nil {
-		return m, err
+		return err
 	}
 
 	// If this was a cut operation and we had to do a manual copy, remove the source
 	if m.copyItems.cut && !sameDev {
 		err = os.RemoveAll(src)
 		if err != nil {
-			return m, fmt.Errorf("failed to remove source after move: %v", err)
+			return fmt.Errorf("failed to remove source after move: %v", err)
 		}
 	}
 
-	return m, nil
+	return nil
 }
