@@ -10,9 +10,12 @@ import (
 var (
 	minimumHeight = 24
 	minimumWidth  = 60
-	footerHeight  = 14
-	modalWidth    = 60
-	modalHeight   = 7
+
+	// Todo : These are model object properties, not global properties
+	// We are modifying them in the code many time. They need to be part of model struct.
+	minFooterHeight = 6
+	modalWidth      = 60
+	modalHeight     = 7
 )
 
 var (
